@@ -290,7 +290,7 @@ static bool lessThanByOffset(const MBoxEntry &left, const MBoxEntry &right)
     return left.messageOffset() < right.messageOffset();
 }
 
-bool MBox::purge(const MBoxEntry::List &deletedEntries, QVector<MBoxEntry::Pair> *movedEntries)
+bool MBox::purge(const MBoxEntry::List &deletedEntries, QList<MBoxEntry::Pair> *movedEntries)
 {
     if (d->mMboxFile.fileName().isEmpty() || d->mReadOnly) {
         return false; // No file loaded yet or it's readOnly
@@ -327,11 +327,11 @@ bool MBox::purge(const MBoxEntry::List &deletedEntries, QVector<MBoxEntry::Pair>
     quint64 writeOffset = 0;
     bool writeOffSetInitialized = false;
     MBoxEntry::List resultingEntryList;
-    QVector<MBoxEntry::Pair> tmpMovedEntries;
+    QList<MBoxEntry::Pair> tmpMovedEntries;
 
     quint64 origFileSize = d->mMboxFile.size();
 
-    QVectorIterator<MBoxEntry> i(d->mEntries);
+    QListIterator<MBoxEntry> i(d->mEntries);
     while (i.hasNext()) {
         MBoxEntry entry = i.next();
 
